"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class PolicyConfiguration:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"enabled": "bool", "parameters": "list[NameValuePair]"}

    attribute_map = {"enabled": "Enabled", "parameters": "Parameters"}

    def __init__(self, enabled=None, parameters=None, _configuration=None):
        """PolicyConfiguration - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._enabled = None
        self._parameters = None
        self.discriminator = None

        if enabled is not None:
            self.enabled = enabled
        if parameters is not None:
            self.parameters = parameters

    @property
    def enabled(self):
        # type: () -> bool
        """Gets the enabled of this PolicyConfiguration.


        :return: The enabled of this PolicyConfiguration.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this PolicyConfiguration.


        :param enabled: The enabled of this PolicyConfiguration.
        :type: bool
        """

        self._enabled = enabled

    @property
    def parameters(self):
        # type: () -> list[NameValuePair]
        """Gets the parameters of this PolicyConfiguration.


        :return: The parameters of this PolicyConfiguration.
        :rtype: list[NameValuePair]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this PolicyConfiguration.


        :param parameters: The parameters of this PolicyConfiguration.
        :type: list[NameValuePair]
        """

        self._parameters = parameters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(PolicyConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PolicyConfiguration):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class SystemWebHttpODataQueryODataRawQueryOptions:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "filter": "str",
        "order_by": "str",
        "top": "str",
        "skip": "str",
        "select": "str",
        "expand": "str",
        "inline_count": "str",
        "format": "str",
        "skip_token": "str",
    }

    attribute_map = {
        "filter": "Filter",
        "order_by": "OrderBy",
        "top": "Top",
        "skip": "Skip",
        "select": "Select",
        "expand": "Expand",
        "inline_count": "InlineCount",
        "format": "Format",
        "skip_token": "SkipToken",
    }

    def __init__(
        self,
        filter=None,
        order_by=None,
        top=None,
        skip=None,
        select=None,
        expand=None,
        inline_count=None,
        format=None,
        skip_token=None,
        _configuration=None,
    ):
        """SystemWebHttpODataQueryODataRawQueryOptions - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._filter = None
        self._order_by = None
        self._top = None
        self._skip = None
        self._select = None
        self._expand = None
        self._inline_count = None
        self._format = None
        self._skip_token = None
        self.discriminator = None

        if filter is not None:
            self.filter = filter
        if order_by is not None:
            self.order_by = order_by
        if top is not None:
            self.top = top
        if skip is not None:
            self.skip = skip
        if select is not None:
            self.select = select
        if expand is not None:
            self.expand = expand
        if inline_count is not None:
            self.inline_count = inline_count
        if format is not None:
            self.format = format
        if skip_token is not None:
            self.skip_token = skip_token

    @property
    def filter(self):
        # type: () -> str
        """Gets the filter of this SystemWebHttpODataQueryODataRawQueryOptions.


        :return: The filter of this SystemWebHttpODataQueryODataRawQueryOptions.
        :rtype: str
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """Sets the filter of this SystemWebHttpODataQueryODataRawQueryOptions.


        :param filter: The filter of this SystemWebHttpODataQueryODataRawQueryOptions.
        :type: str
        """

        self._filter = filter

    @property
    def order_by(self):
        # type: () -> str
        """Gets the order_by of this SystemWebHttpODataQueryODataRawQueryOptions.


        :return: The order_by of this SystemWebHttpODataQueryODataRawQueryOptions.
        :rtype: str
        """
        return self._order_by

    @order_by.setter
    def order_by(self, order_by):
        """Sets the order_by of this SystemWebHttpODataQueryODataRawQueryOptions.


        :param order_by: The order_by of this SystemWebHttpODataQueryODataRawQueryOptions.
        :type: str
        """

        self._order_by = order_by

    @property
    def top(self):
        # type: () -> str
        """Gets the top of this SystemWebHttpODataQueryODataRawQueryOptions.


        :return: The top of this SystemWebHttpODataQueryODataRawQueryOptions.
        :rtype: str
        """
        return self._top

    @top.setter
    def top(self, top):
        """Sets the top of this SystemWebHttpODataQueryODataRawQueryOptions.


        :param top: The top of this SystemWebHttpODataQueryODataRawQueryOptions.
        :type: str
        """

        self._top = top

    @property
    def skip(self):
        # type: () -> str
        """Gets the skip of this SystemWebHttpODataQueryODataRawQueryOptions.


        :return: The skip of this SystemWebHttpODataQueryODataRawQueryOptions.
        :rtype: str
        """
        return self._skip

    @skip.setter
    def skip(self, skip):
        """Sets the skip of this SystemWebHttpODataQueryODataRawQueryOptions.


        :param skip: The skip of this SystemWebHttpODataQueryODataRawQueryOptions.
        :type: str
        """

        self._skip = skip

    @property
    def select(self):
        # type: () -> str
        """Gets the select of this SystemWebHttpODataQueryODataRawQueryOptions.


        :return: The select of this SystemWebHttpODataQueryODataRawQueryOptions.
        :rtype: str
        """
        return self._select

    @select.setter
    def select(self, select):
        """Sets the select of this SystemWebHttpODataQueryODataRawQueryOptions.


        :param select: The select of this SystemWebHttpODataQueryODataRawQueryOptions.
        :type: str
        """

        self._select = select

    @property
    def expand(self):
        # type: () -> str
        """Gets the expand of this SystemWebHttpODataQueryODataRawQueryOptions.


        :return: The expand of this SystemWebHttpODataQueryODataRawQueryOptions.
        :rtype: str
        """
        return self._expand

    @expand.setter
    def expand(self, expand):
        """Sets the expand of this SystemWebHttpODataQueryODataRawQueryOptions.


        :param expand: The expand of this SystemWebHttpODataQueryODataRawQueryOptions.
        :type: str
        """

        self._expand = expand

    @property
    def inline_count(self):
        # type: () -> str
        """Gets the inline_count of this SystemWebHttpODataQueryODataRawQueryOptions.


        :return: The inline_count of this SystemWebHttpODataQueryODataRawQueryOptions.
        :rtype: str
        """
        return self._inline_count

    @inline_count.setter
    def inline_count(self, inline_count):
        """Sets the inline_count of this SystemWebHttpODataQueryODataRawQueryOptions.


        :param inline_count: The inline_count of this SystemWebHttpODataQueryODataRawQueryOptions.
        :type: str
        """

        self._inline_count = inline_count

    @property
    def format(self):
        # type: () -> str
        """Gets the format of this SystemWebHttpODataQueryODataRawQueryOptions.


        :return: The format of this SystemWebHttpODataQueryODataRawQueryOptions.
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this SystemWebHttpODataQueryODataRawQueryOptions.


        :param format: The format of this SystemWebHttpODataQueryODataRawQueryOptions.
        :type: str
        """

        self._format = format

    @property
    def skip_token(self):
        # type: () -> str
        """Gets the skip_token of this SystemWebHttpODataQueryODataRawQueryOptions.


        :return: The skip_token of this SystemWebHttpODataQueryODataRawQueryOptions.
        :rtype: str
        """
        return self._skip_token

    @skip_token.setter
    def skip_token(self, skip_token):
        """Sets the skip_token of this SystemWebHttpODataQueryODataRawQueryOptions.


        :param skip_token: The skip_token of this SystemWebHttpODataQueryODataRawQueryOptions.
        :type: str
        """

        self._skip_token = skip_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(SystemWebHttpODataQueryODataRawQueryOptions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemWebHttpODataQueryODataRawQueryOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SystemWebHttpODataQueryODataRawQueryOptions):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UtilitiesIssueModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "language": "str",
        "severity": "str",
        "status": "str",
        "issue_type": "str",
        "location": "str",
        "date_created": "datetime",
        "last_updated": "datetime",
        "last_found": "datetime",
        "calling_method": "str",
        "is_new_in_scope": "bool",
        "library_name": "str",
        "library_version": "str",
        "sca_technology": "str",
        "fg_status": "str",
        "application_id": "str",
        "fix_group_id": "str",
        "api": "str",
        "source": "str",
        "context": "str",
        "appscan_vuln_id": "str",
        "calling_line": "str",
        "_class": "str",
        "cve": "str",
        "cve_publish_date": "datetime",
        "details_url": "str",
        "cvss": "str",
        "cvss_version": "str",
        "discovery_method": "str",
        "domain": "str",
        "element": "str",
        "element_type": "str",
        "external_id": "str",
        "host": "str",
        "issue_type_id": "str",
        "issue_type_guid": "str",
        "issue_xml": "str",
        "line": "str",
        "package": "str",
        "path": "str",
        "port": "int",
        "scheme": "str",
        "severity_value": "int",
        "correlation_group_id": "str",
        "source_file": "str",
        "last_comment": "datetime",
        "scanner": "str",
        "scan_name": "str",
        "cwe": "int",
        "threat_class_id": "str",
        "diff_result": "str",
        "api_vuln_name": "str",
        "remediation_id": "str",
    }

    attribute_map = {
        "id": "Id",
        "language": "Language",
        "severity": "Severity",
        "status": "Status",
        "issue_type": "IssueType",
        "location": "Location",
        "date_created": "DateCreated",
        "last_updated": "LastUpdated",
        "last_found": "LastFound",
        "calling_method": "CallingMethod",
        "is_new_in_scope": "IsNewInScope",
        "library_name": "LibraryName",
        "library_version": "LibraryVersion",
        "sca_technology": "ScaTechnology",
        "fg_status": "FGStatus",
        "application_id": "ApplicationId",
        "fix_group_id": "FixGroupId",
        "api": "Api",
        "source": "Source",
        "context": "Context",
        "appscan_vuln_id": "AppscanVulnId",
        "calling_line": "CallingLine",
        "_class": "Class",
        "cve": "Cve",
        "cve_publish_date": "CvePublishDate",
        "details_url": "DetailsUrl",
        "cvss": "Cvss",
        "cvss_version": "CvssVersion",
        "discovery_method": "DiscoveryMethod",
        "domain": "Domain",
        "element": "Element",
        "element_type": "ElementType",
        "external_id": "ExternalId",
        "host": "Host",
        "issue_type_id": "IssueTypeId",
        "issue_type_guid": "IssueTypeGuid",
        "issue_xml": "IssueXml",
        "line": "Line",
        "package": "Package",
        "path": "Path",
        "port": "Port",
        "scheme": "Scheme",
        "severity_value": "SeverityValue",
        "correlation_group_id": "CorrelationGroupId",
        "source_file": "SourceFile",
        "last_comment": "LastComment",
        "scanner": "Scanner",
        "scan_name": "ScanName",
        "cwe": "Cwe",
        "threat_class_id": "ThreatClassId",
        "diff_result": "DiffResult",
        "api_vuln_name": "ApiVulnName",
        "remediation_id": "RemediationId",
    }

    def __init__(
        self,
        id=None,
        language=None,
        severity=None,
        status=None,
        issue_type=None,
        location=None,
        date_created=None,
        last_updated=None,
        last_found=None,
        calling_method=None,
        is_new_in_scope=None,
        library_name=None,
        library_version=None,
        sca_technology=None,
        fg_status=None,
        application_id=None,
        fix_group_id=None,
        api=None,
        source=None,
        context=None,
        appscan_vuln_id=None,
        calling_line=None,
        _class=None,
        cve=None,
        cve_publish_date=None,
        details_url=None,
        cvss=None,
        cvss_version=None,
        discovery_method=None,
        domain=None,
        element=None,
        element_type=None,
        external_id=None,
        host=None,
        issue_type_id=None,
        issue_type_guid=None,
        issue_xml=None,
        line=None,
        package=None,
        path=None,
        port=None,
        scheme=None,
        severity_value=None,
        correlation_group_id=None,
        source_file=None,
        last_comment=None,
        scanner=None,
        scan_name=None,
        cwe=None,
        threat_class_id=None,
        diff_result=None,
        api_vuln_name=None,
        remediation_id=None,
        _configuration=None,
    ):
        """UtilitiesIssueModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._language = None
        self._severity = None
        self._status = None
        self._issue_type = None
        self._location = None
        self._date_created = None
        self._last_updated = None
        self._last_found = None
        self._calling_method = None
        self._is_new_in_scope = None
        self._library_name = None
        self._library_version = None
        self._sca_technology = None
        self._fg_status = None
        self._application_id = None
        self._fix_group_id = None
        self._api = None
        self._source = None
        self._context = None
        self._appscan_vuln_id = None
        self._calling_line = None
        self.__class = None
        self._cve = None
        self._cve_publish_date = None
        self._details_url = None
        self._cvss = None
        self._cvss_version = None
        self._discovery_method = None
        self._domain = None
        self._element = None
        self._element_type = None
        self._external_id = None
        self._host = None
        self._issue_type_id = None
        self._issue_type_guid = None
        self._issue_xml = None
        self._line = None
        self._package = None
        self._path = None
        self._port = None
        self._scheme = None
        self._severity_value = None
        self._correlation_group_id = None
        self._source_file = None
        self._last_comment = None
        self._scanner = None
        self._scan_name = None
        self._cwe = None
        self._threat_class_id = None
        self._diff_result = None
        self._api_vuln_name = None
        self._remediation_id = None
        self.discriminator = None

        self.id = id
        if language is not None:
            self.language = language
        if severity is not None:
            self.severity = severity
        if status is not None:
            self.status = status
        if issue_type is not None:
            self.issue_type = issue_type
        if location is not None:
            self.location = location
        if date_created is not None:
            self.date_created = date_created
        if last_updated is not None:
            self.last_updated = last_updated
        if last_found is not None:
            self.last_found = last_found
        if calling_method is not None:
            self.calling_method = calling_method
        if is_new_in_scope is not None:
            self.is_new_in_scope = is_new_in_scope
        if library_name is not None:
            self.library_name = library_name
        if library_version is not None:
            self.library_version = library_version
        if sca_technology is not None:
            self.sca_technology = sca_technology
        if fg_status is not None:
            self.fg_status = fg_status
        if application_id is not None:
            self.application_id = application_id
        if fix_group_id is not None:
            self.fix_group_id = fix_group_id
        if api is not None:
            self.api = api
        if source is not None:
            self.source = source
        if context is not None:
            self.context = context
        if appscan_vuln_id is not None:
            self.appscan_vuln_id = appscan_vuln_id
        if calling_line is not None:
            self.calling_line = calling_line
        if _class is not None:
            self._class = _class
        if cve is not None:
            self.cve = cve
        if cve_publish_date is not None:
            self.cve_publish_date = cve_publish_date
        if details_url is not None:
            self.details_url = details_url
        if cvss is not None:
            self.cvss = cvss
        if cvss_version is not None:
            self.cvss_version = cvss_version
        if discovery_method is not None:
            self.discovery_method = discovery_method
        if domain is not None:
            self.domain = domain
        if element is not None:
            self.element = element
        if element_type is not None:
            self.element_type = element_type
        if external_id is not None:
            self.external_id = external_id
        if host is not None:
            self.host = host
        self.issue_type_id = issue_type_id
        if issue_type_guid is not None:
            self.issue_type_guid = issue_type_guid
        if issue_xml is not None:
            self.issue_xml = issue_xml
        if line is not None:
            self.line = line
        if package is not None:
            self.package = package
        if path is not None:
            self.path = path
        if port is not None:
            self.port = port
        if scheme is not None:
            self.scheme = scheme
        if severity_value is not None:
            self.severity_value = severity_value
        if correlation_group_id is not None:
            self.correlation_group_id = correlation_group_id
        if source_file is not None:
            self.source_file = source_file
        if last_comment is not None:
            self.last_comment = last_comment
        if scanner is not None:
            self.scanner = scanner
        if scan_name is not None:
            self.scan_name = scan_name
        if cwe is not None:
            self.cwe = cwe
        if threat_class_id is not None:
            self.threat_class_id = threat_class_id
        if diff_result is not None:
            self.diff_result = diff_result
        if api_vuln_name is not None:
            self.api_vuln_name = api_vuln_name
        if remediation_id is not None:
            self.remediation_id = remediation_id

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this UtilitiesIssueModel.


        :return: The id of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UtilitiesIssueModel.


        :param id: The id of this UtilitiesIssueModel.
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def language(self):
        # type: () -> str
        """Gets the language of this UtilitiesIssueModel.


        :return: The language of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this UtilitiesIssueModel.


        :param language: The language of this UtilitiesIssueModel.
        :type: str
        """

        self._language = language

    @property
    def severity(self):
        # type: () -> str
        """Gets the severity of this UtilitiesIssueModel.


        :return: The severity of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this UtilitiesIssueModel.


        :param severity: The severity of this UtilitiesIssueModel.
        :type: str
        """
        allowed_values = [
            "Undetermined",
            "Informational",
            "Low",
            "Medium",
            "High",
            "Critical",
        ]
        if self._configuration.client_side_validation and severity not in allowed_values:
            raise ValueError(
                "Invalid value for `severity` ({}), must be one of {}".format(
                    severity, allowed_values
                )
            )

        self._severity = severity

    @property
    def status(self):
        # type: () -> str
        """Gets the status of this UtilitiesIssueModel.


        :return: The status of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UtilitiesIssueModel.


        :param status: The status of this UtilitiesIssueModel.
        :type: str
        """
        allowed_values = [
            "Open",
            "InProgress",
            "Reopened",
            "Noise",
            "Passed",
            "Fixed",
            "New",
        ]
        if self._configuration.client_side_validation and status not in allowed_values:
            raise ValueError(
                f"Invalid value for `status` ({status}), must be one of {allowed_values}"
            )

        self._status = status

    @property
    def issue_type(self):
        # type: () -> str
        """Gets the issue_type of this UtilitiesIssueModel.


        :return: The issue_type of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._issue_type

    @issue_type.setter
    def issue_type(self, issue_type):
        """Sets the issue_type of this UtilitiesIssueModel.


        :param issue_type: The issue_type of this UtilitiesIssueModel.
        :type: str
        """

        self._issue_type = issue_type

    @property
    def location(self):
        # type: () -> str
        """Gets the location of this UtilitiesIssueModel.


        :return: The location of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this UtilitiesIssueModel.


        :param location: The location of this UtilitiesIssueModel.
        :type: str
        """

        self._location = location

    @property
    def date_created(self):
        # type: () -> datetime
        """Gets the date_created of this UtilitiesIssueModel.


        :return: The date_created of this UtilitiesIssueModel.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this UtilitiesIssueModel.


        :param date_created: The date_created of this UtilitiesIssueModel.
        :type: datetime
        """

        self._date_created = date_created

    @property
    def last_updated(self):
        # type: () -> datetime
        """Gets the last_updated of this UtilitiesIssueModel.


        :return: The last_updated of this UtilitiesIssueModel.
        :rtype: datetime
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this UtilitiesIssueModel.


        :param last_updated: The last_updated of this UtilitiesIssueModel.
        :type: datetime
        """

        self._last_updated = last_updated

    @property
    def last_found(self):
        # type: () -> datetime
        """Gets the last_found of this UtilitiesIssueModel.


        :return: The last_found of this UtilitiesIssueModel.
        :rtype: datetime
        """
        return self._last_found

    @last_found.setter
    def last_found(self, last_found):
        """Sets the last_found of this UtilitiesIssueModel.


        :param last_found: The last_found of this UtilitiesIssueModel.
        :type: datetime
        """

        self._last_found = last_found

    @property
    def calling_method(self):
        # type: () -> str
        """Gets the calling_method of this UtilitiesIssueModel.


        :return: The calling_method of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._calling_method

    @calling_method.setter
    def calling_method(self, calling_method):
        """Sets the calling_method of this UtilitiesIssueModel.


        :param calling_method: The calling_method of this UtilitiesIssueModel.
        :type: str
        """

        self._calling_method = calling_method

    @property
    def is_new_in_scope(self):
        # type: () -> bool
        """Gets the is_new_in_scope of this UtilitiesIssueModel.


        :return: The is_new_in_scope of this UtilitiesIssueModel.
        :rtype: bool
        """
        return self._is_new_in_scope

    @is_new_in_scope.setter
    def is_new_in_scope(self, is_new_in_scope):
        """Sets the is_new_in_scope of this UtilitiesIssueModel.


        :param is_new_in_scope: The is_new_in_scope of this UtilitiesIssueModel.
        :type: bool
        """

        self._is_new_in_scope = is_new_in_scope

    @property
    def library_name(self):
        # type: () -> str
        """Gets the library_name of this UtilitiesIssueModel.


        :return: The library_name of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._library_name

    @library_name.setter
    def library_name(self, library_name):
        """Sets the library_name of this UtilitiesIssueModel.


        :param library_name: The library_name of this UtilitiesIssueModel.
        :type: str
        """

        self._library_name = library_name

    @property
    def library_version(self):
        # type: () -> str
        """Gets the library_version of this UtilitiesIssueModel.


        :return: The library_version of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._library_version

    @library_version.setter
    def library_version(self, library_version):
        """Sets the library_version of this UtilitiesIssueModel.


        :param library_version: The library_version of this UtilitiesIssueModel.
        :type: str
        """

        self._library_version = library_version

    @property
    def sca_technology(self):
        # type: () -> str
        """Gets the sca_technology of this UtilitiesIssueModel.


        :return: The sca_technology of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._sca_technology

    @sca_technology.setter
    def sca_technology(self, sca_technology):
        """Sets the sca_technology of this UtilitiesIssueModel.


        :param sca_technology: The sca_technology of this UtilitiesIssueModel.
        :type: str
        """

        self._sca_technology = sca_technology

    @property
    def fg_status(self):
        # type: () -> str
        """Gets the fg_status of this UtilitiesIssueModel.


        :return: The fg_status of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._fg_status

    @fg_status.setter
    def fg_status(self, fg_status):
        """Sets the fg_status of this UtilitiesIssueModel.


        :param fg_status: The fg_status of this UtilitiesIssueModel.
        :type: str
        """
        allowed_values = [
            "Open",
            "InProgress",
            "Reopened",
            "Noise",
            "Passed",
            "Fixed",
            "New",
        ]
        if self._configuration.client_side_validation and fg_status not in allowed_values:
            raise ValueError(
                "Invalid value for `fg_status` ({}), must be one of {}".format(
                    fg_status, allowed_values
                )
            )

        self._fg_status = fg_status

    @property
    def application_id(self):
        # type: () -> str
        """Gets the application_id of this UtilitiesIssueModel.


        :return: The application_id of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this UtilitiesIssueModel.


        :param application_id: The application_id of this UtilitiesIssueModel.
        :type: str
        """

        self._application_id = application_id

    @property
    def fix_group_id(self):
        # type: () -> str
        """Gets the fix_group_id of this UtilitiesIssueModel.


        :return: The fix_group_id of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._fix_group_id

    @fix_group_id.setter
    def fix_group_id(self, fix_group_id):
        """Sets the fix_group_id of this UtilitiesIssueModel.


        :param fix_group_id: The fix_group_id of this UtilitiesIssueModel.
        :type: str
        """

        self._fix_group_id = fix_group_id

    @property
    def api(self):
        # type: () -> str
        """Gets the api of this UtilitiesIssueModel.


        :return: The api of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._api

    @api.setter
    def api(self, api):
        """Sets the api of this UtilitiesIssueModel.


        :param api: The api of this UtilitiesIssueModel.
        :type: str
        """

        self._api = api

    @property
    def source(self):
        # type: () -> str
        """Gets the source of this UtilitiesIssueModel.


        :return: The source of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this UtilitiesIssueModel.


        :param source: The source of this UtilitiesIssueModel.
        :type: str
        """

        self._source = source

    @property
    def context(self):
        # type: () -> str
        """Gets the context of this UtilitiesIssueModel.


        :return: The context of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this UtilitiesIssueModel.


        :param context: The context of this UtilitiesIssueModel.
        :type: str
        """

        self._context = context

    @property
    def appscan_vuln_id(self):
        # type: () -> str
        """Gets the appscan_vuln_id of this UtilitiesIssueModel.


        :return: The appscan_vuln_id of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._appscan_vuln_id

    @appscan_vuln_id.setter
    def appscan_vuln_id(self, appscan_vuln_id):
        """Sets the appscan_vuln_id of this UtilitiesIssueModel.


        :param appscan_vuln_id: The appscan_vuln_id of this UtilitiesIssueModel.
        :type: str
        """

        self._appscan_vuln_id = appscan_vuln_id

    @property
    def calling_line(self):
        # type: () -> str
        """Gets the calling_line of this UtilitiesIssueModel.


        :return: The calling_line of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._calling_line

    @calling_line.setter
    def calling_line(self, calling_line):
        """Sets the calling_line of this UtilitiesIssueModel.


        :param calling_line: The calling_line of this UtilitiesIssueModel.
        :type: str
        """

        self._calling_line = calling_line

    @property
    def _class(self):
        # type: () -> str
        """Gets the _class of this UtilitiesIssueModel.


        :return: The _class of this UtilitiesIssueModel.
        :rtype: str
        """
        return self.__class

    @_class.setter
    def _class(self, _class):
        """Sets the _class of this UtilitiesIssueModel.


        :param _class: The _class of this UtilitiesIssueModel.
        :type: str
        """

        self.__class = _class

    @property
    def cve(self):
        # type: () -> str
        """Gets the cve of this UtilitiesIssueModel.


        :return: The cve of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._cve

    @cve.setter
    def cve(self, cve):
        """Sets the cve of this UtilitiesIssueModel.


        :param cve: The cve of this UtilitiesIssueModel.
        :type: str
        """

        self._cve = cve

    @property
    def cve_publish_date(self):
        # type: () -> datetime
        """Gets the cve_publish_date of this UtilitiesIssueModel.


        :return: The cve_publish_date of this UtilitiesIssueModel.
        :rtype: datetime
        """
        return self._cve_publish_date

    @cve_publish_date.setter
    def cve_publish_date(self, cve_publish_date):
        """Sets the cve_publish_date of this UtilitiesIssueModel.


        :param cve_publish_date: The cve_publish_date of this UtilitiesIssueModel.
        :type: datetime
        """

        self._cve_publish_date = cve_publish_date

    @property
    def details_url(self):
        # type: () -> str
        """Gets the details_url of this UtilitiesIssueModel.


        :return: The details_url of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._details_url

    @details_url.setter
    def details_url(self, details_url):
        """Sets the details_url of this UtilitiesIssueModel.


        :param details_url: The details_url of this UtilitiesIssueModel.
        :type: str
        """

        self._details_url = details_url

    @property
    def cvss(self):
        # type: () -> str
        """Gets the cvss of this UtilitiesIssueModel.


        :return: The cvss of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._cvss

    @cvss.setter
    def cvss(self, cvss):
        """Sets the cvss of this UtilitiesIssueModel.


        :param cvss: The cvss of this UtilitiesIssueModel.
        :type: str
        """

        self._cvss = cvss

    @property
    def cvss_version(self):
        # type: () -> str
        """Gets the cvss_version of this UtilitiesIssueModel.


        :return: The cvss_version of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._cvss_version

    @cvss_version.setter
    def cvss_version(self, cvss_version):
        """Sets the cvss_version of this UtilitiesIssueModel.


        :param cvss_version: The cvss_version of this UtilitiesIssueModel.
        :type: str
        """
        allowed_values = ["None", "Cvss20", "Cvss30", "Cvss31"]
        if self._configuration.client_side_validation and cvss_version not in allowed_values:
            raise ValueError(
                "Invalid value for `cvss_version` ({}), must be one of {}".format(
                    cvss_version, allowed_values
                )
            )

        self._cvss_version = cvss_version

    @property
    def discovery_method(self):
        # type: () -> str
        """Gets the discovery_method of this UtilitiesIssueModel.


        :return: The discovery_method of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._discovery_method

    @discovery_method.setter
    def discovery_method(self, discovery_method):
        """Sets the discovery_method of this UtilitiesIssueModel.


        :param discovery_method: The discovery_method of this UtilitiesIssueModel.
        :type: str
        """

        self._discovery_method = discovery_method

    @property
    def domain(self):
        # type: () -> str
        """Gets the domain of this UtilitiesIssueModel.


        :return: The domain of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this UtilitiesIssueModel.


        :param domain: The domain of this UtilitiesIssueModel.
        :type: str
        """

        self._domain = domain

    @property
    def element(self):
        # type: () -> str
        """Gets the element of this UtilitiesIssueModel.


        :return: The element of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._element

    @element.setter
    def element(self, element):
        """Sets the element of this UtilitiesIssueModel.


        :param element: The element of this UtilitiesIssueModel.
        :type: str
        """

        self._element = element

    @property
    def element_type(self):
        # type: () -> str
        """Gets the element_type of this UtilitiesIssueModel.


        :return: The element_type of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._element_type

    @element_type.setter
    def element_type(self, element_type):
        """Sets the element_type of this UtilitiesIssueModel.


        :param element_type: The element_type of this UtilitiesIssueModel.
        :type: str
        """

        self._element_type = element_type

    @property
    def external_id(self):
        # type: () -> str
        """Gets the external_id of this UtilitiesIssueModel.


        :return: The external_id of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this UtilitiesIssueModel.


        :param external_id: The external_id of this UtilitiesIssueModel.
        :type: str
        """

        self._external_id = external_id

    @property
    def host(self):
        # type: () -> str
        """Gets the host of this UtilitiesIssueModel.


        :return: The host of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this UtilitiesIssueModel.


        :param host: The host of this UtilitiesIssueModel.
        :type: str
        """

        self._host = host

    @property
    def issue_type_id(self):
        # type: () -> str
        """Gets the issue_type_id of this UtilitiesIssueModel.


        :return: The issue_type_id of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._issue_type_id

    @issue_type_id.setter
    def issue_type_id(self, issue_type_id):
        """Sets the issue_type_id of this UtilitiesIssueModel.


        :param issue_type_id: The issue_type_id of this UtilitiesIssueModel.
        :type: str
        """
        if self._configuration.client_side_validation and issue_type_id is None:
            raise ValueError("Invalid value for `issue_type_id`, must not be `None`")

        self._issue_type_id = issue_type_id

    @property
    def issue_type_guid(self):
        # type: () -> str
        """Gets the issue_type_guid of this UtilitiesIssueModel.


        :return: The issue_type_guid of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._issue_type_guid

    @issue_type_guid.setter
    def issue_type_guid(self, issue_type_guid):
        """Sets the issue_type_guid of this UtilitiesIssueModel.


        :param issue_type_guid: The issue_type_guid of this UtilitiesIssueModel.
        :type: str
        """

        self._issue_type_guid = issue_type_guid

    @property
    def issue_xml(self):
        # type: () -> str
        """Gets the issue_xml of this UtilitiesIssueModel.


        :return: The issue_xml of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._issue_xml

    @issue_xml.setter
    def issue_xml(self, issue_xml):
        """Sets the issue_xml of this UtilitiesIssueModel.


        :param issue_xml: The issue_xml of this UtilitiesIssueModel.
        :type: str
        """

        self._issue_xml = issue_xml

    @property
    def line(self):
        # type: () -> str
        """Gets the line of this UtilitiesIssueModel.


        :return: The line of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._line

    @line.setter
    def line(self, line):
        """Sets the line of this UtilitiesIssueModel.


        :param line: The line of this UtilitiesIssueModel.
        :type: str
        """

        self._line = line

    @property
    def package(self):
        # type: () -> str
        """Gets the package of this UtilitiesIssueModel.


        :return: The package of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._package

    @package.setter
    def package(self, package):
        """Sets the package of this UtilitiesIssueModel.


        :param package: The package of this UtilitiesIssueModel.
        :type: str
        """

        self._package = package

    @property
    def path(self):
        # type: () -> str
        """Gets the path of this UtilitiesIssueModel.


        :return: The path of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this UtilitiesIssueModel.


        :param path: The path of this UtilitiesIssueModel.
        :type: str
        """

        self._path = path

    @property
    def port(self):
        # type: () -> int
        """Gets the port of this UtilitiesIssueModel.


        :return: The port of this UtilitiesIssueModel.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this UtilitiesIssueModel.


        :param port: The port of this UtilitiesIssueModel.
        :type: int
        """

        self._port = port

    @property
    def scheme(self):
        # type: () -> str
        """Gets the scheme of this UtilitiesIssueModel.


        :return: The scheme of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._scheme

    @scheme.setter
    def scheme(self, scheme):
        """Sets the scheme of this UtilitiesIssueModel.


        :param scheme: The scheme of this UtilitiesIssueModel.
        :type: str
        """

        self._scheme = scheme

    @property
    def severity_value(self):
        # type: () -> int
        """Gets the severity_value of this UtilitiesIssueModel.


        :return: The severity_value of this UtilitiesIssueModel.
        :rtype: int
        """
        return self._severity_value

    @severity_value.setter
    def severity_value(self, severity_value):
        """Sets the severity_value of this UtilitiesIssueModel.


        :param severity_value: The severity_value of this UtilitiesIssueModel.
        :type: int
        """

        self._severity_value = severity_value

    @property
    def correlation_group_id(self):
        # type: () -> str
        """Gets the correlation_group_id of this UtilitiesIssueModel.


        :return: The correlation_group_id of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._correlation_group_id

    @correlation_group_id.setter
    def correlation_group_id(self, correlation_group_id):
        """Sets the correlation_group_id of this UtilitiesIssueModel.


        :param correlation_group_id: The correlation_group_id of this UtilitiesIssueModel.
        :type: str
        """

        self._correlation_group_id = correlation_group_id

    @property
    def source_file(self):
        # type: () -> str
        """Gets the source_file of this UtilitiesIssueModel.


        :return: The source_file of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._source_file

    @source_file.setter
    def source_file(self, source_file):
        """Sets the source_file of this UtilitiesIssueModel.


        :param source_file: The source_file of this UtilitiesIssueModel.
        :type: str
        """

        self._source_file = source_file

    @property
    def last_comment(self):
        # type: () -> datetime
        """Gets the last_comment of this UtilitiesIssueModel.


        :return: The last_comment of this UtilitiesIssueModel.
        :rtype: datetime
        """
        return self._last_comment

    @last_comment.setter
    def last_comment(self, last_comment):
        """Sets the last_comment of this UtilitiesIssueModel.


        :param last_comment: The last_comment of this UtilitiesIssueModel.
        :type: datetime
        """

        self._last_comment = last_comment

    @property
    def scanner(self):
        # type: () -> str
        """Gets the scanner of this UtilitiesIssueModel.


        :return: The scanner of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._scanner

    @scanner.setter
    def scanner(self, scanner):
        """Sets the scanner of this UtilitiesIssueModel.


        :param scanner: The scanner of this UtilitiesIssueModel.
        :type: str
        """

        self._scanner = scanner

    @property
    def scan_name(self):
        # type: () -> str
        """Gets the scan_name of this UtilitiesIssueModel.


        :return: The scan_name of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._scan_name

    @scan_name.setter
    def scan_name(self, scan_name):
        """Sets the scan_name of this UtilitiesIssueModel.


        :param scan_name: The scan_name of this UtilitiesIssueModel.
        :type: str
        """

        self._scan_name = scan_name

    @property
    def cwe(self):
        # type: () -> int
        """Gets the cwe of this UtilitiesIssueModel.


        :return: The cwe of this UtilitiesIssueModel.
        :rtype: int
        """
        return self._cwe

    @cwe.setter
    def cwe(self, cwe):
        """Sets the cwe of this UtilitiesIssueModel.


        :param cwe: The cwe of this UtilitiesIssueModel.
        :type: int
        """

        self._cwe = cwe

    @property
    def threat_class_id(self):
        # type: () -> str
        """Gets the threat_class_id of this UtilitiesIssueModel.


        :return: The threat_class_id of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._threat_class_id

    @threat_class_id.setter
    def threat_class_id(self, threat_class_id):
        """Sets the threat_class_id of this UtilitiesIssueModel.


        :param threat_class_id: The threat_class_id of this UtilitiesIssueModel.
        :type: str
        """

        self._threat_class_id = threat_class_id

    @property
    def diff_result(self):
        # type: () -> str
        """Gets the diff_result of this UtilitiesIssueModel.


        :return: The diff_result of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._diff_result

    @diff_result.setter
    def diff_result(self, diff_result):
        """Sets the diff_result of this UtilitiesIssueModel.


        :param diff_result: The diff_result of this UtilitiesIssueModel.
        :type: str
        """
        allowed_values = ["NoChange", "Added", "Removed"]
        if self._configuration.client_side_validation and diff_result not in allowed_values:
            raise ValueError(
                "Invalid value for `diff_result` ({}), must be one of {}".format(
                    diff_result, allowed_values
                )
            )

        self._diff_result = diff_result

    @property
    def api_vuln_name(self):
        # type: () -> str
        """Gets the api_vuln_name of this UtilitiesIssueModel.


        :return: The api_vuln_name of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._api_vuln_name

    @api_vuln_name.setter
    def api_vuln_name(self, api_vuln_name):
        """Sets the api_vuln_name of this UtilitiesIssueModel.


        :param api_vuln_name: The api_vuln_name of this UtilitiesIssueModel.
        :type: str
        """

        self._api_vuln_name = api_vuln_name

    @property
    def remediation_id(self):
        # type: () -> str
        """Gets the remediation_id of this UtilitiesIssueModel.


        :return: The remediation_id of this UtilitiesIssueModel.
        :rtype: str
        """
        return self._remediation_id

    @remediation_id.setter
    def remediation_id(self, remediation_id):
        """Sets the remediation_id of this UtilitiesIssueModel.


        :param remediation_id: The remediation_id of this UtilitiesIssueModel.
        :type: str
        """

        self._remediation_id = remediation_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UtilitiesIssueModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UtilitiesIssueModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UtilitiesIssueModel):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""
from __future__ import annotations

import re  # noqa: F401
from typing import TYPE_CHECKING

from pyasoc import api
from pyasoc.api_client import ApiClient

if TYPE_CHECKING:
    from ..models import (
        SystemWebHttpODataPageResultUtilitiesIssueModel,
        UtilitiesUpdateIssue,
    )


class IssuesApi:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def issues_add_comment_by_issueid(self, issue_id, model, **kwargs):
        """Submit a new comment for the issue

        The next function replaces this function to add comment to Issue(s): UpdateIssuesForScope (PUT /api/v2/Issues/{scope}/{scopeId})
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_add_comment_by_issueid(issue_id, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_id: Issue Id (required)
        :param UserSiteCommonModelsCommentModel model: Comment model (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_add_comment_by_issueid_with_http_info(issue_id, model, **kwargs)
        else:
            (data) = self.issues_add_comment_by_issueid_with_http_info(issue_id, model, **kwargs)
            return data

    def issues_add_comment_by_issueid_with_http_info(self, issue_id, model, **kwargs):
        """Submit a new comment for the issue

        The next function replaces this function to add comment to Issue(s): UpdateIssuesForScope (PUT /api/v2/Issues/{scope}/{scopeId})
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_add_comment_by_issueid_with_http_info(issue_id, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_id: Issue Id (required)
        :param UserSiteCommonModelsCommentModel model: Comment model (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["issue_id", "model"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_add_comment_by_issueid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'issue_id' is set
        if self.api_client.client_side_validation and (
            "issue_id" not in params or params["issue_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `issue_id` when calling `issues_add_comment_by_issueid`"
            )
        # verify the required parameter 'model' is set
        if self.api_client.client_side_validation and (
            "model" not in params or params["model"] is None
        ):
            raise ValueError(
                "Missing the required parameter `model` when calling `issues_add_comment_by_issueid`"
            )

        collection_formats = {}

        path_params = {}
        if "issue_id" in params:
            path_params["issueId"] = params["issue_id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "model" in params:
            body_params = params["model"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/{issueId}/Comments",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_advisory_by_issueid(self, issue_id, locale, **kwargs):
        """Get Advisory (Obsolete! Please refer to: GET /api/v2/Reports/Article)

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_advisory_by_issueid(issue_id, locale, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_id:  (required)
        :param str locale:  (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_advisory_by_issueid_with_http_info(issue_id, locale, **kwargs)
        else:
            (data) = self.issues_advisory_by_issueid_with_http_info(issue_id, locale, **kwargs)
            return data

    def issues_advisory_by_issueid_with_http_info(self, issue_id, locale, **kwargs):
        """Get Advisory (Obsolete! Please refer to: GET /api/v2/Reports/Article)

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_advisory_by_issueid_with_http_info(issue_id, locale, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_id:  (required)
        :param str locale:  (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["issue_id", "locale"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_advisory_by_issueid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'issue_id' is set
        if self.api_client.client_side_validation and (
            "issue_id" not in params or params["issue_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `issue_id` when calling `issues_advisory_by_issueid`"
            )
        # verify the required parameter 'locale' is set
        if self.api_client.client_side_validation and (
            "locale" not in params or params["locale"] is None
        ):
            raise ValueError(
                "Missing the required parameter `locale` when calling `issues_advisory_by_issueid`"
            )

        collection_formats = {}

        path_params = {}
        if "issue_id" in params:
            path_params["issueId"] = params["issue_id"]

        query_params = []
        if "locale" in params:
            query_params.append(("locale", params["locale"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/octet-stream"])

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/{issueId}/Advisory",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="file",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_artifacts_by_issueid(self, issue_id, **kwargs):
        """Get the issue details

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_artifacts_by_issueid(issue_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_id: issue id (required)
        :param str locale: locale (default value: en-US)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_artifacts_by_issueid_with_http_info(issue_id, **kwargs)
        else:
            (data) = self.issues_artifacts_by_issueid_with_http_info(issue_id, **kwargs)
            return data

    def issues_artifacts_by_issueid_with_http_info(self, issue_id, **kwargs):
        """Get the issue details

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_artifacts_by_issueid_with_http_info(issue_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_id: issue id (required)
        :param str locale: locale (default value: en-US)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["issue_id", "locale"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_artifacts_by_issueid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'issue_id' is set
        if self.api_client.client_side_validation and (
            "issue_id" not in params or params["issue_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `issue_id` when calling `issues_artifacts_by_issueid`"
            )

        collection_formats = {}

        path_params = {}
        if "issue_id" in params:
            path_params["issueId"] = params["issue_id"]

        query_params = []
        if "locale" in params:
            query_params.append(("locale", params["locale"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/octet-stream"])

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/{issueId}/Artifacts",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="file",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_fix_recommendation_by_issueid(self, issue_id, locale, **kwargs):
        """Get Fix Recommendation. (Obsolete! Please refer to: GET /api/v2/Reports/Article)

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_fix_recommendation_by_issueid(issue_id, locale, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_id:  (required)
        :param str locale:  (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_fix_recommendation_by_issueid_with_http_info(
                issue_id, locale, **kwargs
            )
        else:
            (data) = self.issues_fix_recommendation_by_issueid_with_http_info(
                issue_id, locale, **kwargs
            )
            return data

    def issues_fix_recommendation_by_issueid_with_http_info(self, issue_id, locale, **kwargs):
        """Get Fix Recommendation. (Obsolete! Please refer to: GET /api/v2/Reports/Article)

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_fix_recommendation_by_issueid_with_http_info(issue_id, locale, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_id:  (required)
        :param str locale:  (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["issue_id", "locale"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_fix_recommendation_by_issueid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'issue_id' is set
        if self.api_client.client_side_validation and (
            "issue_id" not in params or params["issue_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `issue_id` when calling `issues_fix_recommendation_by_issueid`"
            )
        # verify the required parameter 'locale' is set
        if self.api_client.client_side_validation and (
            "locale" not in params or params["locale"] is None
        ):
            raise ValueError(
                "Missing the required parameter `locale` when calling `issues_fix_recommendation_by_issueid`"
            )

        collection_formats = {}

        path_params = {}
        if "issue_id" in params:
            path_params["issueId"] = params["issue_id"]

        query_params = []
        if "locale" in params:
            query_params.append(("locale", params["locale"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/octet-stream"])

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/{issueId}/FixRecommendation",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="file",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_get_comments_by_issueid(self, issue_id, **kwargs):
        """Get all issue's comments

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_comments_by_issueid(issue_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_id: Issue ID (required)
        :return: list[UserSiteCommonModelsCommentModelResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_get_comments_by_issueid_with_http_info(issue_id, **kwargs)
        else:
            (data) = self.issues_get_comments_by_issueid_with_http_info(issue_id, **kwargs)
            return data

    def issues_get_comments_by_issueid_with_http_info(self, issue_id, **kwargs):
        """Get all issue's comments

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_comments_by_issueid_with_http_info(issue_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_id: Issue ID (required)
        :return: list[UserSiteCommonModelsCommentModelResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["issue_id"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_get_comments_by_issueid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'issue_id' is set
        if self.api_client.client_side_validation and (
            "issue_id" not in params or params["issue_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `issue_id` when calling `issues_get_comments_by_issueid`"
            )

        collection_formats = {}

        path_params = {}
        if "issue_id" in params:
            path_params["issueId"] = params["issue_id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/{issueId}/Comments",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[UserSiteCommonModelsCommentModelResponse]",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_get_is_noise(self, **kwargs):
        """Determine if there are similar issues that are marked as noise

        At least one of the hash versions should be provided.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_is_noise(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_hash_0: Will be searched only in hash version 0
        :param str issue_hash_1: Will be searched only in hash version 1
        :param str issue_hash_2: Will be searched only in hash version 2
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_get_is_noise_with_http_info(**kwargs)
        else:
            (data) = self.issues_get_is_noise_with_http_info(**kwargs)
            return data

    def issues_get_is_noise_with_http_info(self, **kwargs):
        """Determine if there are similar issues that are marked as noise

        At least one of the hash versions should be provided.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_is_noise_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_hash_0: Will be searched only in hash version 0
        :param str issue_hash_1: Will be searched only in hash version 1
        :param str issue_hash_2: Will be searched only in hash version 2
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["issue_hash_0", "issue_hash_1", "issue_hash_2"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method issues_get_is_noise" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "issue_hash_0" in params:
            query_params.append(("issueHash_0", params["issue_hash_0"]))
        if "issue_hash_1" in params:
            query_params.append(("issueHash_1", params["issue_hash_1"]))
        if "issue_hash_2" in params:
            query_params.append(("issueHash_2", params["issue_hash_2"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/IsNoise",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="bool",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_get_is_noise1(self, hashes, **kwargs):
        """Determine if there are similar issues that are marked as noise

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_is_noise1(hashes, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str hashes: Comma separated list of hash version and hash valeu. i.e. 0:4543342,1:-5543232,2:34453456,... (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_get_is_noise1_with_http_info(hashes, **kwargs)
        else:
            (data) = self.issues_get_is_noise1_with_http_info(hashes, **kwargs)
            return data

    def issues_get_is_noise1_with_http_info(self, hashes, **kwargs):
        """Determine if there are similar issues that are marked as noise

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_is_noise1_with_http_info(hashes, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str hashes: Comma separated list of hash version and hash valeu. i.e. 0:4543342,1:-5543232,2:34453456,... (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["hashes"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_get_is_noise1" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'hashes' is set
        if self.api_client.client_side_validation and (
            "hashes" not in params or params["hashes"] is None
        ):
            raise ValueError(
                "Missing the required parameter `hashes` when calling `issues_get_is_noise1`"
            )

        collection_formats = {}

        path_params = {}

        query_params = []
        if "hashes" in params:
            query_params.append(("hashes", params["hashes"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/IsNoise1",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="bool",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_get_is_noise2(self, issues_hashes, **kwargs):
        """Check a bulk of issues hashes and determine which of them belong to noise issues

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_is_noise2(issues_hashes, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserSiteCommonModelsVerAndHashes issues_hashes: (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_get_is_noise2_with_http_info(issues_hashes, **kwargs)
        else:
            (data) = self.issues_get_is_noise2_with_http_info(issues_hashes, **kwargs)
            return data

    def issues_get_is_noise2_with_http_info(self, issues_hashes, **kwargs):
        """Check a bulk of issues hashes and determine which of them belong to noise issues

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_is_noise2_with_http_info(issues_hashes, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserSiteCommonModelsVerAndHashes issues_hashes: (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["issues_hashes"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_get_is_noise2" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'issues_hashes' is set
        if self.api_client.client_side_validation and (
            "issues_hashes" not in params or params["issues_hashes"] is None
        ):
            raise ValueError(
                "Missing the required parameter `issues_hashes` when calling `issues_get_is_noise2`"
            )

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "issues_hashes" in params:
            body_params = params["issues_hashes"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/IsNoise",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[str]",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_get_issue_by_id(self, id, **kwargs):
        """issues_get_issue_by_id

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_issue_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str locale:
        :return: UtilitiesIssueModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_get_issue_by_id_with_http_info(id, **kwargs)
        else:
            (data) = self.issues_get_issue_by_id_with_http_info(id, **kwargs)
            return data

    def issues_get_issue_by_id_with_http_info(self, id, **kwargs):
        """issues_get_issue_by_id

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_issue_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str locale:
        :return: UtilitiesIssueModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id", "locale"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_get_issue_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `issues_get_issue_by_id`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []
        if "locale" in params:
            query_params.append(("locale", params["locale"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Issues/{id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UtilitiesIssueModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_get_issues_count_by_severity_for_scope(self, scope, scope_id, **kwargs):
        """Get filtered issues count by severity

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_issues_count_by_severity_for_scope(scope, scope_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the issues (required)
        :param str scope_id: id of the Scope (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param str odata_filter: Odata filter that will be applied
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :return: list[UserSiteCommonModelsIssuesCountBySeverity]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_get_issues_count_by_severity_for_scope_with_http_info(
                scope, scope_id, **kwargs
            )
        else:
            (data) = self.issues_get_issues_count_by_severity_for_scope_with_http_info(
                scope, scope_id, **kwargs
            )
            return data

    def issues_get_issues_count_by_severity_for_scope_with_http_info(
        self, scope, scope_id, **kwargs
    ):
        """Get filtered issues count by severity

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_issues_count_by_severity_for_scope_with_http_info(scope, scope_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the issues (required)
        :param str scope_id: id of the Scope (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param str odata_filter: Odata filter that will be applied
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :return: list[UserSiteCommonModelsIssuesCountBySeverity]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "scope",
            "scope_id",
            "apply_policies",
            "odata_filter",
            "select_policy_ids",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_get_issues_count_by_severity_for_scope" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and (
            "scope" not in params or params["scope"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope` when calling `issues_get_issues_count_by_severity_for_scope`"
            )
        # verify the required parameter 'scope_id' is set
        if self.api_client.client_side_validation and (
            "scope_id" not in params or params["scope_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope_id` when calling `issues_get_issues_count_by_severity_for_scope`"
            )

        collection_formats = {}

        path_params = {}
        if "scope" in params:
            path_params["scope"] = params["scope"]
        if "scope_id" in params:
            path_params["scopeId"] = params["scope_id"]

        query_params = []
        if "apply_policies" in params:
            query_params.append(("applyPolicies", params["apply_policies"]))
        if "odata_filter" in params:
            query_params.append(("odataFilter", params["odata_filter"]))
        if "select_policy_ids" in params:
            query_params.append(("selectPolicyIds", params["select_policy_ids"]))
            collection_formats["selectPolicyIds"] = "multi"

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/CountBySeverity/{scope}/{scopeId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[UserSiteCommonModelsIssuesCountBySeverity]",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_get_issues_count_by_status_for_scope(self, scope, scope_id, **kwargs):
        """Get filtered issues count by status

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_issues_count_by_status_for_scope(scope, scope_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the issues (required)
        :param str scope_id: id of the Scope (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param str odata_filter: Odata filter that will be applied
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :return: list[UserSiteCommonModelsIssuesCountByStatus]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_get_issues_count_by_status_for_scope_with_http_info(
                scope, scope_id, **kwargs
            )
        else:
            (data) = self.issues_get_issues_count_by_status_for_scope_with_http_info(
                scope, scope_id, **kwargs
            )
            return data

    def issues_get_issues_count_by_status_for_scope_with_http_info(self, scope, scope_id, **kwargs):
        """Get filtered issues count by status

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_issues_count_by_status_for_scope_with_http_info(scope, scope_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the issues (required)
        :param str scope_id: id of the Scope (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param str odata_filter: Odata filter that will be applied
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :return: list[UserSiteCommonModelsIssuesCountByStatus]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "scope",
            "scope_id",
            "apply_policies",
            "odata_filter",
            "select_policy_ids",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_get_issues_count_by_status_for_scope" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and (
            "scope" not in params or params["scope"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope` when calling `issues_get_issues_count_by_status_for_scope`"
            )
        # verify the required parameter 'scope_id' is set
        if self.api_client.client_side_validation and (
            "scope_id" not in params or params["scope_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope_id` when calling `issues_get_issues_count_by_status_for_scope`"
            )

        collection_formats = {}

        path_params = {}
        if "scope" in params:
            path_params["scope"] = params["scope"]
        if "scope_id" in params:
            path_params["scopeId"] = params["scope_id"]

        query_params = []
        if "apply_policies" in params:
            query_params.append(("applyPolicies", params["apply_policies"]))
        if "odata_filter" in params:
            query_params.append(("odataFilter", params["odata_filter"]))
        if "select_policy_ids" in params:
            query_params.append(("selectPolicyIds", params["select_policy_ids"]))
            collection_formats["selectPolicyIds"] = "multi"

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/CountByStatus/{scope}/{scopeId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[UserSiteCommonModelsIssuesCountByStatus]",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_get_issues_for_scope_by_scope_and_scopeid(
        self, scope, scope_id, **kwargs
    ) -> SystemWebHttpODataPageResultUtilitiesIssueModel:
        """Get filtered issues

        OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_issues_for_scope_by_scope_and_scopeid(scope, scope_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the issues (required)
        :param str scope_id: id of the Scope (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :param str locale: If provided, it overrides the Accept-Language header. (If not provided and there is no Accept-Language header, the locale will be: en-US)
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :param str inlinecount: Specifies that the response to the request MUST include the count of the number of entities in the collection of entities.
        :return: SystemWebHttpODataPageResultUtilitiesIssueModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_get_issues_for_scope_by_scope_and_scopeid_with_http_info(
                scope, scope_id, **kwargs
            )
        else:
            (data) = self.issues_get_issues_for_scope_by_scope_and_scopeid_with_http_info(
                scope, scope_id, **kwargs
            )
            return data

    def issues_get_issues_for_scope_by_scope_and_scopeid_with_http_info(
        self, scope, scope_id, **kwargs
    ):
        """Get filtered issues

        OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_get_issues_for_scope_by_scope_and_scopeid_with_http_info(scope, scope_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str scope: The Scope of the issues (required)
        :param str scope_id: id of the Scope (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :param str locale: If provided, it overrides the Accept-Language header. (If not provided and there is no Accept-Language header, the locale will be: en-US)
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :param str inlinecount: Specifies that the response to the request MUST include the count of the number of entities in the collection of entities.
        :return: SystemWebHttpODataPageResultUtilitiesIssueModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "scope",
            "scope_id",
            "apply_policies",
            "select_policy_ids",
            "locale",
            "top",
            "skip",
            "filter",
            "select",
            "orderby",
            "expand",
            "inlinecount",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_get_issues_for_scope_by_scope_and_scopeid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and (
            "scope" not in params or params["scope"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope` when calling `issues_get_issues_for_scope_by_scope_and_scopeid`"
            )
        # verify the required parameter 'scope_id' is set
        if self.api_client.client_side_validation and (
            "scope_id" not in params or params["scope_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope_id` when calling `issues_get_issues_for_scope_by_scope_and_scopeid`"
            )

        collection_formats = {}

        path_params = {}
        if "scope" in params:
            path_params["scope"] = params["scope"]
        if "scope_id" in params:
            path_params["scopeId"] = params["scope_id"]

        query_params = []
        if "apply_policies" in params:
            query_params.append(("applyPolicies", params["apply_policies"]))
        if "select_policy_ids" in params:
            query_params.append(("selectPolicyIds", params["select_policy_ids"]))
            collection_formats["selectPolicyIds"] = "multi"
        if "locale" in params:
            query_params.append(("locale", params["locale"]))
        if "top" in params:
            query_params.append(("$top", params["top"]))
        if "skip" in params:
            query_params.append(("$skip", params["skip"]))
        if "filter" in params:
            query_params.append(("$filter", params["filter"]))
        if "select" in params:
            query_params.append(("$select", params["select"]))
        if "orderby" in params:
            query_params.append(("$orderby", params["orderby"]))
        if "expand" in params:
            query_params.append(("$expand", params["expand"]))
        if "inlinecount" in params:
            query_params.append(("$inlinecount", params["inlinecount"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/{scope}/{scopeId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SystemWebHttpODataPageResultUtilitiesIssueModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_history_by_issueid(self, issue_id, **kwargs):
        """Get issue history

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_history_by_issueid(issue_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_id:  (required)
        :param bool include_all_scan_executions: If set to true, the history will contain all the scan executions that found this issue
        :param str locale: locale (default value: en-US)
        :return: list[AppScanSaaSModelsV2IssueChangeSet]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_history_by_issueid_with_http_info(issue_id, **kwargs)
        else:
            (data) = self.issues_history_by_issueid_with_http_info(issue_id, **kwargs)
            return data

    def issues_history_by_issueid_with_http_info(self, issue_id, **kwargs):
        """Get issue history

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_history_by_issueid_with_http_info(issue_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str issue_id:  (required)
        :param bool include_all_scan_executions: If set to true, the history will contain all the scan executions that found this issue
        :param str locale: locale (default value: en-US)
        :return: list[AppScanSaaSModelsV2IssueChangeSet]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["issue_id", "include_all_scan_executions", "locale"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_history_by_issueid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'issue_id' is set
        if self.api_client.client_side_validation and (
            "issue_id" not in params or params["issue_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `issue_id` when calling `issues_history_by_issueid`"
            )

        collection_formats = {}

        path_params = {}
        if "issue_id" in params:
            path_params["issueId"] = params["issue_id"]

        query_params = []
        if "include_all_scan_executions" in params:
            query_params.append(("includeAllScanExecutions", params["include_all_scan_executions"]))
        if "locale" in params:
            query_params.append(("locale", params["locale"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/{issueId}/History",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[AppScanSaaSModelsV2IssueChangeSet]",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_import_file(self, file_to_upload, app_id, scan_name, **kwargs):
        """Import issues from uploaded file to application specified with id

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_import_file(file_to_upload, app_id, scan_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file_to_upload: (required)
        :param str app_id: Application ID (required)
        :param str scan_name: Scan Name (required)
        :param str file_name: If provided, this parameter will override the name of the uploaded file, including its extension(CSV).
        :return: UserSiteCommonModelsImportIssueStatusModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_import_file_with_http_info(
                file_to_upload, app_id, scan_name, **kwargs
            )
        else:
            (data) = self.issues_import_file_with_http_info(
                file_to_upload, app_id, scan_name, **kwargs
            )
            return data

    def issues_import_file_with_http_info(self, file_to_upload, app_id, scan_name, **kwargs):
        """Import issues from uploaded file to application specified with id

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_import_file_with_http_info(file_to_upload, app_id, scan_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file_to_upload: (required)
        :param str app_id: Application ID (required)
        :param str scan_name: Scan Name (required)
        :param str file_name: If provided, this parameter will override the name of the uploaded file, including its extension(CSV).
        :return: UserSiteCommonModelsImportIssueStatusModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "file_to_upload",
            "app_id",
            "scan_name",
            "file_name",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method issues_import_file" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'file_to_upload' is set
        if self.api_client.client_side_validation and (
            "file_to_upload" not in params or params["file_to_upload"] is None
        ):
            raise ValueError(
                "Missing the required parameter `file_to_upload` when calling `issues_import_file`"
            )
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and (
            "app_id" not in params or params["app_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `app_id` when calling `issues_import_file`"
            )
        # verify the required parameter 'scan_name' is set
        if self.api_client.client_side_validation and (
            "scan_name" not in params or params["scan_name"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scan_name` when calling `issues_import_file`"
            )

        if self.api_client.client_side_validation and (
            "file_name" in params and len(params["file_name"]) > 2048
        ):
            raise ValueError(
                "Invalid value for parameter `file_name` when calling `issues_import_file`, length must be less than or equal to `2048`"
            )
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if "file_to_upload" in params:
            local_var_files["fileToUpload"] = params["file_to_upload"]
        if "file_name" in params:
            form_params.append(("fileName", params["file_name"]))
        if "app_id" in params:
            form_params.append(("appId", params["app_id"]))
        if "scan_name" in params:
            form_params.append(("scanName", params["scan_name"]))

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["multipart/form-data"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Issues/ImportFile",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsImportIssueStatusModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_update_issue_by_id(self, id, issue_data: UtilitiesUpdateIssue, **kwargs):
        """Modify issue data

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_update_issue_by_id(id, issue_data, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of issue to be modified (required)
        :param UtilitiesUpdateIssue issue_data: New issue data (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_update_issue_by_id_with_http_info(id, issue_data, **kwargs)
        else:
            (data) = self.issues_update_issue_by_id_with_http_info(id, issue_data, **kwargs)
            return data

    def issues_update_issue_by_id_with_http_info(self, id, issue_data, **kwargs):
        """Modify issue data

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_update_issue_by_id_with_http_info(id, issue_data, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: ID of issue to be modified (required)
        :param UtilitiesUpdateIssue issue_data: New issue data (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id", "issue_data"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_update_issue_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `issues_update_issue_by_id`"
            )
        # verify the required parameter 'issue_data' is set
        if self.api_client.client_side_validation and (
            "issue_data" not in params or params["issue_data"] is None
        ):
            raise ValueError(
                "Missing the required parameter `issue_data` when calling `issues_update_issue_by_id`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "issue_data" in params:
            body_params = params["issue_data"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Issues/{id}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def issues_update_issues_for_scope_by_scope_and_scopeid(
        self, issue_data, scope, scope_id, odata_filter, **kwargs
    ):
        """Update filtered issues

        The NUpdatedIssues value in the response counts only issues whose the status was updated. <br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_update_issues_for_scope_by_scope_and_scopeid(issue_data, scope, scope_id, odata_filter, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UtilitiesUpdateIssue issue_data: New issue data (required)
        :param str scope: The Scope of the issues (required)
        :param str scope_id: id of the Scope (required)
        :param str odata_filter: Odata filter that will be applied (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :return: UserSiteCommonModelsTriageResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.issues_update_issues_for_scope_by_scope_and_scopeid_with_http_info(
                issue_data, scope, scope_id, odata_filter, **kwargs
            )
        else:
            (data) = self.issues_update_issues_for_scope_by_scope_and_scopeid_with_http_info(
                issue_data, scope, scope_id, odata_filter, **kwargs
            )
            return data

    def issues_update_issues_for_scope_by_scope_and_scopeid_with_http_info(
        self, issue_data, scope, scope_id, odata_filter, **kwargs
    ):
        """Update filtered issues

        The NUpdatedIssues value in the response counts only issues whose the status was updated. <br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.issues_update_issues_for_scope_by_scope_and_scopeid_with_http_info(issue_data, scope, scope_id, odata_filter, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UtilitiesUpdateIssue issue_data: New issue data (required)
        :param str scope: The Scope of the issues (required)
        :param str scope_id: id of the Scope (required)
        :param str odata_filter: Odata filter that will be applied (required)
        :param str apply_policies: Determine which policies will be applied for filtering in non compliant issues
        :param list[str] select_policy_ids: If applyPolicies is set to Select, only issues that are not compliant with these policies will be filtered in
        :return: UserSiteCommonModelsTriageResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "issue_data",
            "scope",
            "scope_id",
            "odata_filter",
            "apply_policies",
            "select_policy_ids",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method issues_update_issues_for_scope_by_scope_and_scopeid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'issue_data' is set
        if self.api_client.client_side_validation and (
            "issue_data" not in params or params["issue_data"] is None
        ):
            raise ValueError(
                "Missing the required parameter `issue_data` when calling `issues_update_issues_for_scope_by_scope_and_scopeid`"
            )
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and (
            "scope" not in params or params["scope"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope` when calling `issues_update_issues_for_scope_by_scope_and_scopeid`"
            )
        # verify the required parameter 'scope_id' is set
        if self.api_client.client_side_validation and (
            "scope_id" not in params or params["scope_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `scope_id` when calling `issues_update_issues_for_scope_by_scope_and_scopeid`"
            )
        # verify the required parameter 'odata_filter' is set
        if self.api_client.client_side_validation and (
            "odata_filter" not in params or params["odata_filter"] is None
        ):
            raise ValueError(
                "Missing the required parameter `odata_filter` when calling `issues_update_issues_for_scope_by_scope_and_scopeid`"
            )

        collection_formats = {}

        path_params = {}
        if "scope" in params:
            path_params["scope"] = params["scope"]
        if "scope_id" in params:
            path_params["scopeId"] = params["scope_id"]

        query_params = []
        if "odata_filter" in params:
            query_params.append(("odataFilter", params["odata_filter"]))
        if "apply_policies" in params:
            query_params.append(("applyPolicies", params["apply_policies"]))
        if "select_policy_ids" in params:
            query_params.append(("selectPolicyIds", params["select_policy_ids"]))
            collection_formats["selectPolicyIds"] = "multi"

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "issue_data" in params:
            body_params = params["issue_data"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Issues/{scope}/{scopeId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsTriageResult",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class PolicyAssociation:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "enabled": "bool",
        "parameters": "list[NameValuePair]",
        "id": "str",
        "name": "str",
        "description": "str",
        "predefined": "bool",
        "created_at": "datetime",
        "created_by": "str",
        "n_associated_apps": "int",
        "expression": "object",
        "type": "str",
        "category": "str",
        "region": "str",
        "ui_features": "str",
    }

    attribute_map = {
        "enabled": "Enabled",
        "parameters": "Parameters",
        "id": "Id",
        "name": "Name",
        "description": "Description",
        "predefined": "Predefined",
        "created_at": "CreatedAt",
        "created_by": "CreatedBy",
        "n_associated_apps": "NAssociatedApps",
        "expression": "Expression",
        "type": "Type",
        "category": "Category",
        "region": "Region",
        "ui_features": "UIFeatures",
    }

    def __init__(
        self,
        enabled=None,
        parameters=None,
        id=None,
        name=None,
        description=None,
        predefined=None,
        created_at=None,
        created_by=None,
        n_associated_apps=None,
        expression=None,
        type=None,
        category=None,
        region=None,
        ui_features=None,
        _configuration=None,
    ):
        """PolicyAssociation - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._enabled = None
        self._parameters = None
        self._id = None
        self._name = None
        self._description = None
        self._predefined = None
        self._created_at = None
        self._created_by = None
        self._n_associated_apps = None
        self._expression = None
        self._type = None
        self._category = None
        self._region = None
        self._ui_features = None
        self.discriminator = None

        if enabled is not None:
            self.enabled = enabled
        if parameters is not None:
            self.parameters = parameters
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if predefined is not None:
            self.predefined = predefined
        if created_at is not None:
            self.created_at = created_at
        if created_by is not None:
            self.created_by = created_by
        if n_associated_apps is not None:
            self.n_associated_apps = n_associated_apps
        if expression is not None:
            self.expression = expression
        if type is not None:
            self.type = type
        if category is not None:
            self.category = category
        if region is not None:
            self.region = region
        if ui_features is not None:
            self.ui_features = ui_features

    @property
    def enabled(self):
        # type: () -> bool
        """Gets the enabled of this PolicyAssociation.


        :return: The enabled of this PolicyAssociation.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this PolicyAssociation.


        :param enabled: The enabled of this PolicyAssociation.
        :type: bool
        """

        self._enabled = enabled

    @property
    def parameters(self):
        # type: () -> list[NameValuePair]
        """Gets the parameters of this PolicyAssociation.


        :return: The parameters of this PolicyAssociation.
        :rtype: list[NameValuePair]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this PolicyAssociation.


        :param parameters: The parameters of this PolicyAssociation.
        :type: list[NameValuePair]
        """

        self._parameters = parameters

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this PolicyAssociation.


        :return: The id of this PolicyAssociation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PolicyAssociation.


        :param id: The id of this PolicyAssociation.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this PolicyAssociation.


        :return: The name of this PolicyAssociation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PolicyAssociation.


        :param name: The name of this PolicyAssociation.
        :type: str
        """

        self._name = name

    @property
    def description(self):
        # type: () -> str
        """Gets the description of this PolicyAssociation.


        :return: The description of this PolicyAssociation.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PolicyAssociation.


        :param description: The description of this PolicyAssociation.
        :type: str
        """

        self._description = description

    @property
    def predefined(self):
        # type: () -> bool
        """Gets the predefined of this PolicyAssociation.


        :return: The predefined of this PolicyAssociation.
        :rtype: bool
        """
        return self._predefined

    @predefined.setter
    def predefined(self, predefined):
        """Sets the predefined of this PolicyAssociation.


        :param predefined: The predefined of this PolicyAssociation.
        :type: bool
        """

        self._predefined = predefined

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this PolicyAssociation.


        :return: The created_at of this PolicyAssociation.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PolicyAssociation.


        :param created_at: The created_at of this PolicyAssociation.
        :type: datetime
        """

        self._created_at = created_at

    @property
    def created_by(self):
        # type: () -> str
        """Gets the created_by of this PolicyAssociation.


        :return: The created_by of this PolicyAssociation.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this PolicyAssociation.


        :param created_by: The created_by of this PolicyAssociation.
        :type: str
        """

        self._created_by = created_by

    @property
    def n_associated_apps(self):
        # type: () -> int
        """Gets the n_associated_apps of this PolicyAssociation.


        :return: The n_associated_apps of this PolicyAssociation.
        :rtype: int
        """
        return self._n_associated_apps

    @n_associated_apps.setter
    def n_associated_apps(self, n_associated_apps):
        """Sets the n_associated_apps of this PolicyAssociation.


        :param n_associated_apps: The n_associated_apps of this PolicyAssociation.
        :type: int
        """

        self._n_associated_apps = n_associated_apps

    @property
    def expression(self):
        # type: () -> object
        """Gets the expression of this PolicyAssociation.


        :return: The expression of this PolicyAssociation.
        :rtype: object
        """
        return self._expression

    @expression.setter
    def expression(self, expression):
        """Sets the expression of this PolicyAssociation.


        :param expression: The expression of this PolicyAssociation.
        :type: object
        """

        self._expression = expression

    @property
    def type(self):
        # type: () -> str
        """Gets the type of this PolicyAssociation.


        :return: The type of this PolicyAssociation.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PolicyAssociation.


        :param type: The type of this PolicyAssociation.
        :type: str
        """
        allowed_values = [
            "None",
            "OwaspTop10_2017",
            "Sans25",
            "EuGdpr_2016",
            "PCI",
            "Hipaa",
            "OwaspTop10Mobile_2016",
            "ISO27001",
            "ISO27002",
            "Wasc",
            "Nist",
            "Sox",
            "Fisma",
            "Fippa",
            "Efta",
            "DisaStig",
            "Padss",
            "OwaspTop10_2021",
            "OwaspTop10OpenApi_2019",
            "Ccpa",
        ]
        if self._configuration.client_side_validation and type not in allowed_values:
            raise ValueError(f"Invalid value for `type` ({type}), must be one of {allowed_values}")

        self._type = type

    @property
    def category(self):
        # type: () -> str
        """Gets the category of this PolicyAssociation.


        :return: The category of this PolicyAssociation.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this PolicyAssociation.


        :param category: The category of this PolicyAssociation.
        :type: str
        """
        allowed_values = [
            "Custom",
            "Security",
            "Regulation",
            "IndustryStandard",
        ]
        if self._configuration.client_side_validation and category not in allowed_values:
            raise ValueError(
                "Invalid value for `category` ({}), must be one of {}".format(
                    category, allowed_values
                )
            )

        self._category = category

    @property
    def region(self):
        # type: () -> str
        """Gets the region of this PolicyAssociation.


        :return: The region of this PolicyAssociation.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this PolicyAssociation.


        :param region: The region of this PolicyAssociation.
        :type: str
        """
        allowed_values = [
            "Global",
            "US",
            "UK",
            "Canada",
            "EU",
            "Japan",
            "AUS",
        ]
        if self._configuration.client_side_validation and region not in allowed_values:
            raise ValueError(
                f"Invalid value for `region` ({region}), must be one of {allowed_values}"
            )

        self._region = region

    @property
    def ui_features(self):
        # type: () -> str
        """Gets the ui_features of this PolicyAssociation.


        :return: The ui_features of this PolicyAssociation.
        :rtype: str
        """
        return self._ui_features

    @ui_features.setter
    def ui_features(self, ui_features):
        """Sets the ui_features of this PolicyAssociation.


        :param ui_features: The ui_features of this PolicyAssociation.
        :type: str
        """

        self._ui_features = ui_features

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(PolicyAssociation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyAssociation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PolicyAssociation):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class AppScanSaaSModelsV2NewWebhook:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "presence_id": "str",
        "uri": "str",
        "_global": "bool",
        "asset_group_id": "str",
        "event": "str",
    }

    attribute_map = {
        "presence_id": "PresenceId",
        "uri": "Uri",
        "_global": "Global",
        "asset_group_id": "AssetGroupId",
        "event": "Event",
    }

    def __init__(
        self,
        presence_id=None,
        uri=None,
        _global=None,
        asset_group_id=None,
        event=None,
        _configuration=None,
    ):
        """AppScanSaaSModelsV2NewWebhook - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._presence_id = None
        self._uri = None
        self.__global = None
        self._asset_group_id = None
        self._event = None
        self.discriminator = None

        self.presence_id = presence_id
        self.uri = uri
        if _global is not None:
            self._global = _global
        if asset_group_id is not None:
            self.asset_group_id = asset_group_id
        self.event = event

    @property
    def presence_id(self):
        # type: () -> str
        """Gets the presence_id of this AppScanSaaSModelsV2NewWebhook.


        :return: The presence_id of this AppScanSaaSModelsV2NewWebhook.
        :rtype: str
        """
        return self._presence_id

    @presence_id.setter
    def presence_id(self, presence_id):
        """Sets the presence_id of this AppScanSaaSModelsV2NewWebhook.


        :param presence_id: The presence_id of this AppScanSaaSModelsV2NewWebhook.
        :type: str
        """
        if self._configuration.client_side_validation and presence_id is None:
            raise ValueError("Invalid value for `presence_id`, must not be `None`")

        self._presence_id = presence_id

    @property
    def uri(self):
        # type: () -> str
        """Gets the uri of this AppScanSaaSModelsV2NewWebhook.


        :return: The uri of this AppScanSaaSModelsV2NewWebhook.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this AppScanSaaSModelsV2NewWebhook.


        :param uri: The uri of this AppScanSaaSModelsV2NewWebhook.
        :type: str
        """
        if self._configuration.client_side_validation and uri is None:
            raise ValueError("Invalid value for `uri`, must not be `None`")
        if self._configuration.client_side_validation and uri is not None and len(uri) > 2048:
            raise ValueError("Invalid value for `uri`, length must be less than or equal to `2048`")
        if self._configuration.client_side_validation and uri is not None and len(uri) < 0:
            raise ValueError("Invalid value for `uri`, length must be greater than or equal to `0`")

        self._uri = uri

    @property
    def _global(self):
        # type: () -> bool
        """Gets the _global of this AppScanSaaSModelsV2NewWebhook.


        :return: The _global of this AppScanSaaSModelsV2NewWebhook.
        :rtype: bool
        """
        return self.__global

    @_global.setter
    def _global(self, _global):
        """Sets the _global of this AppScanSaaSModelsV2NewWebhook.


        :param _global: The _global of this AppScanSaaSModelsV2NewWebhook.
        :type: bool
        """

        self.__global = _global

    @property
    def asset_group_id(self):
        # type: () -> str
        """Gets the asset_group_id of this AppScanSaaSModelsV2NewWebhook.


        :return: The asset_group_id of this AppScanSaaSModelsV2NewWebhook.
        :rtype: str
        """
        return self._asset_group_id

    @asset_group_id.setter
    def asset_group_id(self, asset_group_id):
        """Sets the asset_group_id of this AppScanSaaSModelsV2NewWebhook.


        :param asset_group_id: The asset_group_id of this AppScanSaaSModelsV2NewWebhook.
        :type: str
        """

        self._asset_group_id = asset_group_id

    @property
    def event(self):
        # type: () -> str
        """Gets the event of this AppScanSaaSModelsV2NewWebhook.


        :return: The event of this AppScanSaaSModelsV2NewWebhook.
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this AppScanSaaSModelsV2NewWebhook.


        :param event: The event of this AppScanSaaSModelsV2NewWebhook.
        :type: str
        """
        if self._configuration.client_side_validation and event is None:
            raise ValueError("Invalid value for `event`, must not be `None`")
        allowed_values = ["ScanExecutionCompleted", "ApplicationUpdated"]
        if self._configuration.client_side_validation and event not in allowed_values:
            raise ValueError(
                f"Invalid value for `event` ({event}), must be one of {allowed_values}"
            )

        self._event = event

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(AppScanSaaSModelsV2NewWebhook, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppScanSaaSModelsV2NewWebhook):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AppScanSaaSModelsV2NewWebhook):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "if_match": "object",
        "if_none_match": "object",
        "context": "SystemWebHttpODataODataQueryContext",
        "request": "object",
        "raw_values": "SystemWebHttpODataQueryODataRawQueryOptions",
        "select_expand": "SystemWebHttpODataQuerySelectExpandQueryOption",
        "filter": "SystemWebHttpODataQueryFilterQueryOption",
        "order_by": "SystemWebHttpODataQueryOrderByQueryOption",
        "skip": "SystemWebHttpODataQuerySkipQueryOption",
        "top": "SystemWebHttpODataQueryTopQueryOption",
        "inline_count": "SystemWebHttpODataQueryInlineCountQueryOption",
        "validator": "SystemWebHttpODataQueryValidatorsODataQueryValidator",
    }

    attribute_map = {
        "if_match": "IfMatch",
        "if_none_match": "IfNoneMatch",
        "context": "Context",
        "request": "Request",
        "raw_values": "RawValues",
        "select_expand": "SelectExpand",
        "filter": "Filter",
        "order_by": "OrderBy",
        "skip": "Skip",
        "top": "Top",
        "inline_count": "InlineCount",
        "validator": "Validator",
    }

    def __init__(
        self,
        if_match=None,
        if_none_match=None,
        context=None,
        request=None,
        raw_values=None,
        select_expand=None,
        filter=None,
        order_by=None,
        skip=None,
        top=None,
        inline_count=None,
        validator=None,
        _configuration=None,
    ):
        """SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1 - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._if_match = None
        self._if_none_match = None
        self._context = None
        self._request = None
        self._raw_values = None
        self._select_expand = None
        self._filter = None
        self._order_by = None
        self._skip = None
        self._top = None
        self._inline_count = None
        self._validator = None
        self.discriminator = None

        if if_match is not None:
            self.if_match = if_match
        if if_none_match is not None:
            self.if_none_match = if_none_match
        if context is not None:
            self.context = context
        if request is not None:
            self.request = request
        if raw_values is not None:
            self.raw_values = raw_values
        if select_expand is not None:
            self.select_expand = select_expand
        if filter is not None:
            self.filter = filter
        if order_by is not None:
            self.order_by = order_by
        if skip is not None:
            self.skip = skip
        if top is not None:
            self.top = top
        if inline_count is not None:
            self.inline_count = inline_count
        if validator is not None:
            self.validator = validator

    @property
    def if_match(self):
        # type: () -> object
        """Gets the if_match of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :return: The if_match of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :rtype: object
        """
        return self._if_match

    @if_match.setter
    def if_match(self, if_match):
        """Sets the if_match of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :param if_match: The if_match of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :type: object
        """

        self._if_match = if_match

    @property
    def if_none_match(self):
        # type: () -> object
        """Gets the if_none_match of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :return: The if_none_match of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :rtype: object
        """
        return self._if_none_match

    @if_none_match.setter
    def if_none_match(self, if_none_match):
        """Sets the if_none_match of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :param if_none_match: The if_none_match of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :type: object
        """

        self._if_none_match = if_none_match

    @property
    def context(self):
        # type: () -> SystemWebHttpODataODataQueryContext
        """Gets the context of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :return: The context of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :rtype: SystemWebHttpODataODataQueryContext
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :param context: The context of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :type: SystemWebHttpODataODataQueryContext
        """

        self._context = context

    @property
    def request(self):
        # type: () -> object
        """Gets the request of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :return: The request of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :rtype: object
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :param request: The request of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :type: object
        """

        self._request = request

    @property
    def raw_values(self):
        # type: () -> SystemWebHttpODataQueryODataRawQueryOptions
        """Gets the raw_values of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :return: The raw_values of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :rtype: SystemWebHttpODataQueryODataRawQueryOptions
        """
        return self._raw_values

    @raw_values.setter
    def raw_values(self, raw_values):
        """Sets the raw_values of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :param raw_values: The raw_values of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :type: SystemWebHttpODataQueryODataRawQueryOptions
        """

        self._raw_values = raw_values

    @property
    def select_expand(self):
        # type: () -> SystemWebHttpODataQuerySelectExpandQueryOption
        """Gets the select_expand of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :return: The select_expand of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :rtype: SystemWebHttpODataQuerySelectExpandQueryOption
        """
        return self._select_expand

    @select_expand.setter
    def select_expand(self, select_expand):
        """Sets the select_expand of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :param select_expand: The select_expand of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :type: SystemWebHttpODataQuerySelectExpandQueryOption
        """

        self._select_expand = select_expand

    @property
    def filter(self):
        # type: () -> SystemWebHttpODataQueryFilterQueryOption
        """Gets the filter of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :return: The filter of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :rtype: SystemWebHttpODataQueryFilterQueryOption
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """Sets the filter of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :param filter: The filter of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :type: SystemWebHttpODataQueryFilterQueryOption
        """

        self._filter = filter

    @property
    def order_by(self):
        # type: () -> SystemWebHttpODataQueryOrderByQueryOption
        """Gets the order_by of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :return: The order_by of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :rtype: SystemWebHttpODataQueryOrderByQueryOption
        """
        return self._order_by

    @order_by.setter
    def order_by(self, order_by):
        """Sets the order_by of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :param order_by: The order_by of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :type: SystemWebHttpODataQueryOrderByQueryOption
        """

        self._order_by = order_by

    @property
    def skip(self):
        # type: () -> SystemWebHttpODataQuerySkipQueryOption
        """Gets the skip of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :return: The skip of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :rtype: SystemWebHttpODataQuerySkipQueryOption
        """
        return self._skip

    @skip.setter
    def skip(self, skip):
        """Sets the skip of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :param skip: The skip of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :type: SystemWebHttpODataQuerySkipQueryOption
        """

        self._skip = skip

    @property
    def top(self):
        # type: () -> SystemWebHttpODataQueryTopQueryOption
        """Gets the top of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :return: The top of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :rtype: SystemWebHttpODataQueryTopQueryOption
        """
        return self._top

    @top.setter
    def top(self, top):
        """Sets the top of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :param top: The top of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :type: SystemWebHttpODataQueryTopQueryOption
        """

        self._top = top

    @property
    def inline_count(self):
        # type: () -> SystemWebHttpODataQueryInlineCountQueryOption
        """Gets the inline_count of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :return: The inline_count of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :rtype: SystemWebHttpODataQueryInlineCountQueryOption
        """
        return self._inline_count

    @inline_count.setter
    def inline_count(self, inline_count):
        """Sets the inline_count of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :param inline_count: The inline_count of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :type: SystemWebHttpODataQueryInlineCountQueryOption
        """

        self._inline_count = inline_count

    @property
    def validator(self):
        # type: () -> SystemWebHttpODataQueryValidatorsODataQueryValidator
        """Gets the validator of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :return: The validator of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :rtype: SystemWebHttpODataQueryValidatorsODataQueryValidator
        """
        return self._validator

    @validator.setter
    def validator(self, validator):
        """Sets the validator of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.


        :param validator: The validator of this SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1.
        :type: SystemWebHttpODataQueryValidatorsODataQueryValidator
        """

        self._validator = validator

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SystemWebHttpODataQueryODataQueryOptionsAppScanSaaSModelsV2Scan1):
            return True

        return self.to_dict() != other.to_dict()
